/*
** Copyright (C) 10 Feb 1999 Jonas Munsin <jmunsin@iki.fi>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software 
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

typedef struct {
	char *buffer; /* the complete buffer minus newline bellow */
	char *newline; /* last recently extracted line */
} linebuffer;

char *string_append(char *, const char *);
int extract_line(linebuffer *, char *);
void add_to_buffer(linebuffer *, char *);
void init_buffer(linebuffer *);
void destroy_buffer(linebuffer *);
